/*****************************************************************************
 * Copyright (c) 2015 CEA LIST.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Benoit Maggi (CEA LIST) benoit.maggi@cea.fr - Initial API and implementation
 *****************************************************************************/
package org.eclipse.papyrus.sysml14.diagram.common;

import org.eclipse.draw2d.PositionConstants;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.papyrus.sysml14.deprecatedelements.FlowPort;
import org.eclipse.papyrus.sysml14.portsandflows.FlowDirection;
import org.eclipse.swt.graphics.Image;
import org.eclipse.ui.plugin.AbstractUIPlugin;

/**
 * The activator class controls the plug-in life cycle
 */
public class Activator extends AbstractUIPlugin {

	// The plug-in ID
	public static final String PLUGIN_ID = "org.eclipse.papyrus.sysml14.diagram.common"; //$NON-NLS-1$

	/**
	 * Returns an image descriptor for the image file at the given
	 * plug-in relative path
	 *
	 * @param path
	 *            the path
	 * @return the image descriptor
	 */
	public static ImageDescriptor getImageDescriptor(String path) {
		return imageDescriptorFromPlugin(PLUGIN_ID, path);
	}
	
	
	
	/**
	 * <pre>
	 * Provide a FlowPort image for border edit part that take the border item position
	 * into account.
	 *
	 * The image is not rotated, but predefined.
	 *
	 * The side of the image (relatively to the parent figure) can be:
	 *         <ul>
	 *         <li>{@linkplain PositionConstants#NORTH}</li>
	 *         <li> {@linkplain PositionConstants#SOUTH}</li>
	 *         <li> {@linkplain PositionConstants#EAST}</li>
	 *         <li> {@linkplain PositionConstants#WEST}</li>
	 *         <li> {@linkplain PositionConstants#NORTH_EAST}</li>
	 *         <li> {@linkplain PositionConstants#NORTH_WEST}</li>
	 *         <li> {@linkplain PositionConstants#SOUTH_EAST}</li>
	 *         <li> {@linkplain PositionConstants#SOUTH_WEST}</li>
	 *         </ul>
	 *
	 * </pre>
	 */
	public Image getFlowPortImage(FlowPort flowport, int side) {
		Image image = null;
		if (flowport!=null){
			// Prepare the image key
			String imageKey = "FlowPort_";
			if (flowport.isAtomic()) {
				if (flowport.getDirection() == FlowDirection.IN) {
					imageKey = imageKey + "IN_";
				} else if (flowport.getDirection() == FlowDirection.OUT) {
					imageKey = imageKey + "OUT_";
				} else if (flowport.getDirection() == FlowDirection.INOUT) {
					imageKey = imageKey + "INOUT_";
				}

				imageKey = imageKey + "A_";
			} else {
				imageKey = imageKey + "NA_";
			}

			if (side == PositionConstants.WEST) {
				imageKey = imageKey + "WEST";
			} else if (side == PositionConstants.NORTH) {
				imageKey = imageKey + "NORTH";
			} else if (side == PositionConstants.SOUTH) {
				imageKey = imageKey + "SOUTH";
			} else if (side == PositionConstants.EAST) {
				imageKey = imageKey + "EAST";
			} else if (side == PositionConstants.NORTH_WEST) {
				imageKey = imageKey + "NORTH_WEST";
			} else if (side == PositionConstants.NORTH_EAST) {
				imageKey = imageKey + "NORTH_EAST";
			} else if (side == PositionConstants.SOUTH_EAST) {
				imageKey = imageKey + "SOUTH_EAST";
			} else if (side == PositionConstants.SOUTH_WEST) {
				imageKey = imageKey + "SOUTH_WEST";
			}

			// Retrieve image from registry or add it in the registry
			image = getImageRegistry().get(imageKey);
			if (image == null) {

				ImageDescriptor imageDescriptor = imageDescriptorFromPlugin(PLUGIN_ID, "resources/icons/" + imageKey + ".gif");

				if (imageDescriptor == null) {
					imageDescriptor = ImageDescriptor.getMissingImageDescriptor();
				}
				getImageRegistry().put(imageKey, imageDescriptor);
				image = getImageRegistry().get(imageKey);
			}			
		}
		return image;
	}

}
