/*****************************************************************************
 * Copyright (c) 2016 CEA LIST and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Benoit Maggi (CEA LIST) benoit.maggi@cea.fr - Initial API and implementation
 *   
 *****************************************************************************/

package org.eclipse.papyrus.sysml14.diagram.common.internal.edit.provider;

import org.eclipse.emf.common.util.EList;
import org.eclipse.gef.EditPart;
import org.eclipse.gmf.runtime.common.core.service.AbstractProvider;
import org.eclipse.gmf.runtime.common.core.service.IOperation;
import org.eclipse.gmf.runtime.diagram.ui.editparts.IPrimaryEditPart;
import org.eclipse.gmf.runtime.diagram.ui.services.editpolicy.IEditPolicyProvider;
import org.eclipse.gmf.runtime.notation.View;
import org.eclipse.papyrus.infra.gmfdiag.common.editpart.IPapyrusEditPart;
import org.eclipse.papyrus.infra.gmfdiag.common.utils.DiagramUtils;
import org.eclipse.papyrus.infra.viewpoints.configuration.Category;
import org.eclipse.papyrus.infra.viewpoints.configuration.PapyrusView;
import org.eclipse.papyrus.infra.viewpoints.style.PapyrusViewStyle;
import org.eclipse.papyrus.sysml14.viewpoint.util.ViewpointUtil;
import org.eclipse.papyrus.uml.diagram.stereotype.edition.editpart.AppliedStereotypeMultilinePropertyEditPart;
import org.eclipse.papyrus.uml.diagram.stereotype.edition.editpolicies.AppliedStereotypeCommentEditPolicy;
import org.eclipse.papyrus.uml.diagram.stereotype.edition.provider.CustomEditPolicyProvider;

/**
 * Provider that disable CustomEditPolicyProvider/AppliedStereotypeCommentEditPolicy.APPLIED_STEREOTYPE_COMMENT to improve performance
 */
public class RemoveAppliedStereotypeCommentEditPolicyProvider extends AbstractProvider implements IEditPolicyProvider {

	public CustomEditPolicyProvider customEditPolicyProvider = new CustomEditPolicyProvider();

	/**
	 * {@inheritDoc}
	 */
	@Override
	public boolean provides(IOperation operation) {
		return customEditPolicyProvider.provides(operation);
	}

	/**
	 * {@inheritDoc}
	 */
	@Override
	public void createEditPolicies(EditPart editPart) {
		if (editPart instanceof IPapyrusEditPart) {
			if (!(editPart instanceof AppliedStereotypeMultilinePropertyEditPart)) {
				if (editPart instanceof IPrimaryEditPart) {
					Object model = editPart.getModel();
					if (model instanceof View){
						View view = (View) model;
						PapyrusViewStyle papyrusViewStyle = DiagramUtils.getPapyrusViewStyle(view.getDiagram());
						if (papyrusViewStyle != null){
							PapyrusView configuration = papyrusViewStyle.getConfiguration();
							if (configuration != null){
								EList<Category> categories = configuration.getCategories();
								for (Category category : categories) {
									if (ViewpointUtil.SYSML14_CATEGORY_NAME.equals(category.getName())){
										editPart.installEditPolicy(AppliedStereotypeCommentEditPolicy.APPLIED_STEREOTYPE_COMMENT, null);
									}						
								}								
							}							
						}
					}
				}
			}
		}
	}

}
