/*****************************************************************************
 * Copyright (c) 2016 CEA LIST and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Benoit Maggi (CEA LIST) benoit.maggi@cea.fr - Initial API and implementation
 *   
 *****************************************************************************/
package org.eclipse.papyrus.sysml14.validation.rules.activities;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.emf.validation.AbstractModelConstraint;
import org.eclipse.emf.validation.IValidationContext;
import org.eclipse.papyrus.sysml14.activities.Continuous;
import org.eclipse.papyrus.sysml14.activities.Discrete;
import org.eclipse.uml2.uml.ActivityEdge;
import org.eclipse.uml2.uml.ObjectNode;
import org.eclipse.uml2.uml.Parameter;
import org.eclipse.uml2.uml.util.UMLUtil;

/**
 * 
 * 11.3.2.3 Discrete [1] The «discrete» and «continuous» stereotypes cannot be
 * applied to the same element at the same time.
 */
public class DiscreteNoContinuousModelConstraint extends AbstractModelConstraint {

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.emf.validation.AbstractModelConstraint#validate(org.eclipse.
	 * emf.validation.IValidationContext)
	 */
	@Override
	public IStatus validate(IValidationContext context) {
		Discrete noBuffer = (Discrete) context.getTarget();

		Parameter parameter = noBuffer.getBase_Parameter();
		if (parameter != null) {
			if (UMLUtil.getStereotypeApplication(parameter, Continuous.class) != null) {
				return context.createFailureStatus(context.getTarget());
			}
		}

		ObjectNode objectNode = noBuffer.getBase_ObjectNode();
		if (objectNode != null) {
			if (UMLUtil.getStereotypeApplication(objectNode, Continuous.class) != null) {
				return context.createFailureStatus(context.getTarget());
			}
		}

		ActivityEdge activityEdge = noBuffer.getBase_ActivityEdge();
		if (activityEdge != null) {
			if (UMLUtil.getStereotypeApplication(activityEdge, Continuous.class) != null) {
				return context.createFailureStatus(context.getTarget());
			}
		}

		return context.createSuccessStatus();
	}

}
