/*****************************************************************************
 * Copyright (c) 2016 CEA LIST and others.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Benoit Maggi (CEA LIST) benoit.maggi@cea.fr - Initial API and implementation
 *   
 *****************************************************************************/
package org.eclipse.papyrus.sysml14.validation.rules.blocks;

import java.util.Set;

import org.eclipse.core.runtime.IStatus;
import org.eclipse.emf.transaction.util.TransactionUtil;
import org.eclipse.emf.validation.AbstractModelConstraint;
import org.eclipse.emf.validation.IValidationContext;
import org.eclipse.gmf.runtime.emf.core.util.CrossReferenceAdapter;
import org.eclipse.papyrus.sysml14.blocks.Block;
import org.eclipse.uml2.uml.Association;
import org.eclipse.uml2.uml.Class;
import org.eclipse.uml2.uml.Property;
import org.eclipse.uml2.uml.UMLPackage;

/**
 * 8.3.2.3 Block [3] In the UML metamodel on which SysML is built, any instance
 * of the Property metaclass that is typed by a block (a Class with the «block»
 * stereotype applied) and which is owned by an Association may not have a name
 * and may not be defined as a navigable owned end of the association. (While
 * the Property has a «name» property as defined by its NamedElement
 */
public class BlockPropertyNoNameModelConstraint extends AbstractModelConstraint {

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * org.eclipse.emf.validation.AbstractModelConstraint#validate(org.eclipse.
	 * emf.validation.IValidationContext)
	 */
	@Override
	public IStatus validate(IValidationContext context) {
		Block block = (Block) context.getTarget();
		Class clazz = block.getBase_Class();
		if (clazz != null) {
			CrossReferenceAdapter crossReferenceAdapter = CrossReferenceAdapter
					.getCrossReferenceAdapter(TransactionUtil.getEditingDomain(clazz).getResourceSet());
			Set inverseReferencers = crossReferenceAdapter.getInverseReferencers(clazz,
					UMLPackage.eINSTANCE.getTypedElement_Type(), null);
			for (Object object : inverseReferencers) {
				if (object instanceof Property) {
					Property property = (Property) object;
					Association association = property.getAssociation();
					if (association != null) {
						String name = property.getName();
						if (name != null && !"".equals(name)) {
							return context.createFailureStatus(context.getTarget());
						}
					}
				}
			}
		}
		return context.createSuccessStatus();
	}

}
